@@ -23,6 +23,11 @@ KW_METHOD = 'method'
 
 KW_RESOURCE = 'resource'
 
+PYTHON_FRAMEWORK_MODULE_NAME = 'python_framework'
+PYTHON_FRAMEWORK_INTERNAL_MODULE_NAME_LIST = [
+    'python_framework',
+    'TestApi'
+]
 KW_CONTROLLER_RESOURCE = 'Controller'
 KW_SERVICE_RESOURCE = 'Service'
 KW_CLIENT_RESOURCE = 'Client'
@@ -31,16 +36,35 @@ KW_VALIDATOR_RESOURCE = 'Validator'
 KW_MAPPER_RESOURCE = 'Mapper'
 KW_HELPER_RESOURCE = 'Helper'
 KW_CONVERTER_RESOURCE = 'Converter'
-KW_RESOURCE_LIST = [
-    KW_CONTROLLER_RESOURCE,
-    KW_SERVICE_RESOURCE,
-    KW_CLIENT_RESOURCE,
-    KW_REPOSITORY_RESOURCE,
-    KW_VALIDATOR_RESOURCE,
-    KW_MAPPER_RESOURCE,
-    KW_HELPER_RESOURCE,
-    KW_CONVERTER_RESOURCE
-]
+PYTHON_FRAMEWORK_RESOURCE_NAME_DICTIONARY = {
+    KW_CONTROLLER_RESOURCE : [
+        'ActuatorHealthController'
+    ],
+    KW_SERVICE_RESOURCE : [
+        'ActuatorHealthService'
+    ],
+    KW_CLIENT_RESOURCE : [],
+    KW_REPOSITORY_RESOURCE : [
+        'ActuatorHealthRepository'
+    ],
+    KW_VALIDATOR_RESOURCE : [],
+    KW_MAPPER_RESOURCE : [],
+    KW_HELPER_RESOURCE : [],
+    KW_CONVERTER_RESOURCE : [
+        'ActuatorHealthConverter'
+    ]
+}
+KW_RESOURCE_LIST = list(PYTHON_FRAMEWORK_RESOURCE_NAME_DICTIONARY.keys())
+# KW_RESOURCE_LIST = [
+#     KW_CONTROLLER_RESOURCE,
+#     KW_SERVICE_RESOURCE,
+#     KW_CLIENT_RESOURCE,
+#     KW_REPOSITORY_RESOURCE,
+#     KW_VALIDATOR_RESOURCE,
+#     KW_MAPPER_RESOURCE,
+#     KW_HELPER_RESOURCE,
+#     KW_CONVERTER_RESOURCE
+# ]
 
 def runGlobals(
     filePath
